@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2002 Open Source Telecom Corporation.
+// Copyright (C) 1999-2005 Open Source Telecom Corporation.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -14,29 +14,26 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
-// As a special exception to the GNU General Public License, permission is
-// granted for additional uses of the text contained in its release
-// of Common C++.
+// As a special exception, you may use this file as part of a free software
+// library without restriction.  Specifically, if other files instantiate
+// templates or use macros or inline functions from this file, or you compile
+// this file and link it with other files to produce an executable, this
+// file does not by itself cause the resulting executable to be covered by
+// the GNU General Public License.  This exception does not however    
+// invalidate any other reasons why the executable file might be covered by
+// the GNU General Public License.    
 //
-// The exception is that, if you link the Common C++ library with other
-// files to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the Common C++ library code into it.
-//
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-//
-// This exception applies only to the code released under the
-// name Common C++.  If you copy code from other releases into a copy of
+// This exception applies only to the code released under the name GNU
+// Common C++.  If you copy code from other releases into a copy of GNU
 // Common C++, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
 // anyone as to the status of such modified files, you must delete
 // this exception notice from them.
 //
-// If you write modifications of your own for Common C++, it is your
-// choice whether to permit this exception to apply to your modifications.
+// If you write modifications of your own for GNU Common C++, it is your choice
+// whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.
+//
 
 /**
  * @file file.h
@@ -494,8 +491,7 @@ protected:
 	 *
 	 * @return access, or attrInvalid if should be removed.
 	 */
-	virtual Attr initialize(void)
-		{return attrPublic;};
+	virtual Attr initialize(void);
 
 	/**
 	 * Close the file.
@@ -506,8 +502,7 @@ public:
 	/**
 	 * Destroy a random access file or it's derived class.
 	 */
-	virtual ~RandomFile()
-		{final();};
+	virtual ~RandomFile();
 
 	/**
 	 * This method should be called right after a RandomFile derived
@@ -531,8 +526,7 @@ public:
 	 * database.  This may be used when the database has been unlinked
 	 * and an external process provides a new one to use.
 	 */
-	virtual Error restart(void)
-		{return errOpenFailed;};
+	virtual Error restart(void);
 
 	/**
 	 * Return current error id.
@@ -599,8 +593,7 @@ public:
 	 *
 	 * @return errSuccess if successful.
 	 */
-	Error restart(void)
-		{return open(pathname);};
+	Error restart(void);
 
 	/**
 	 * Fetch a portion of the file into physical memory.  This can use
@@ -754,7 +747,6 @@ public:
  *
  * @author David Sugar <dyfet@ostel.com>
  * @short Map a named disk file into memory.
- * @todo implement in win32
  */
 class __EXPORT MappedFile : public RandomFile
 {
@@ -983,6 +975,11 @@ public:
 	 * @return true if valid.
 	 */
 	bool isValid(void);
+
+	/**
+	 * Install debug handler...
+	 */
+	static void setDebug(void);
 };
 
 /** @relates RandomFile */
