@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2002 Open Source Telecom Corporation.
+// Copyright (C) 1999-2005 Open Source Telecom Corporation.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -14,29 +14,26 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// As a special exception to the GNU General Public License, permission is 
-// granted for additional uses of the text contained in its release 
-// of Common C++.
-// 
-// The exception is that, if you link the Common C++ library with other files
-// to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the Common C++ library code into it.
+// As a special exception, you may use this file as part of a free software
+// library without restriction.  Specifically, if other files instantiate
+// templates or use macros or inline functions from this file, or you compile
+// this file and link it with other files to produce an executable, this
+// file does not by itself cause the resulting executable to be covered by
+// the GNU General Public License.  This exception does not however    
+// invalidate any other reasons why the executable file might be covered by
+// the GNU General Public License.    
 //
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-//
-// This exception applies only to the code released under the 
-// name Common C++.  If you copy code from other releases into a copy of
+// This exception applies only to the code released under the name GNU
+// Common C++.  If you copy code from other releases into a copy of GNU
 // Common C++, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
 // anyone as to the status of such modified files, you must delete
 // this exception notice from them.
-// 
-// If you write modifications of your own for Common C++, it is your choice
+//
+// If you write modifications of your own for GNU Common C++, it is your choice
 // whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.
+//
 
 /**
  * @file serial.h
@@ -306,8 +303,7 @@ public:
 	 * assuring the socket base class is a virtual destructor, we
 	 * can assure the full object is properly terminated.
 	 */
-	virtual ~Serial()
-		{endSerial();};
+	virtual ~Serial();
 
 	/**
 	 * Serial ports may also be duplecated by the assignment
@@ -672,7 +668,7 @@ protected:
 	/**
 	 * Get the current state of the DetectPending flag.
 	 */
-	bool getDetectPending( void ) const
+	inline bool getDetectPending( void ) const
 		{ return detect_pending; }
 	
 	/**
@@ -684,30 +680,27 @@ protected:
 	/**
 	 * Get the current state of the DetectOutput flag.
 	 */
-	bool getDetectOutput( void ) const
+	inline bool getDetectOutput( void ) const
 		{ return detect_output; }
 
 	/**
 	 * Called by the service thread when the objects timer
 	 * has expired.
 	 */
-	virtual void expired(void)
-		{return;};
+	virtual void expired(void);
 
 	/**
 	 * Called by the service thread when input data is pending
 	 * for this tty port.  Effected by setPacketInput and by
 	 * setLineInput.
 	 */
-	virtual void pending(void)
-		{return;};
+	virtual void pending(void);
 
 	/**
 	 * Called by the service thread when an exception has occured
 	 * such as a hangup.
 	 */
-	virtual void disconnect(void)
-		{return;};
+	virtual void disconnect(void);
 
 	/**
 	 * Transmit "send" data to the serial port.  This is not public
@@ -720,11 +713,11 @@ protected:
 	 */
 	inline int output(void *buf, int len)
 		{return aWrite((char *)buf, len);};
+
 	/**
 	 * Perform when output is available for sending data.
 	 */
-	virtual void output(void)
-		{return;};
+	virtual void output(void);
 
 	/**
 	 * Receive "input" for pending data from the serial port.  This
@@ -814,15 +807,13 @@ protected:
 	 *
 	 * @param flag of update request.
 	 */
-	virtual void onUpdate(unsigned char flag)
-		{return;};
+	virtual void onUpdate(unsigned char flag);
 
 	/**
 	 * A virtual handler for event loop calls.  This can be
  	 * used to extend event loop processing.
 	 */
-	virtual void onEvent(void)
-		{return;};
+	virtual void onEvent(void);
 
 	/**
 	 * A virtual handler for adding support for additional
@@ -830,8 +821,7 @@ protected:
 	 *
 	 * @param port serial port currently being evaluated.
 	 */
-	virtual void onCallback(SerialPort *port)
-		{return;};
+	virtual void onCallback(SerialPort *port);
 
 public:
 	/**
