@@ -2305,7 +2305,7 @@ void TCPSocket::reject(void)
 #ifdef	CCXX_IPV6
 void TCPV6Socket::reject(void)
 {
-        int rej = accept(so, NULL, NULL);
+        SOCKET rej = accept(so, NULL, NULL);
         shutdown(rej, 2);
 #ifdef WIN32
         closesocket(rej);
@@ -2688,7 +2688,7 @@ void TCPStream::connect(const IPV6Host &host, tpport_t port, unsigned mss)
 			
 			// timeout check for connect completion
 
-			if(::select(so + 1, NULL, &fds, NULL, &to) < 1)
+			if(::select(((int)(so)) + 1, NULL, &fds, NULL, &to) < 1)
 				continue;
 
 			getsockopt(so, SOL_SOCKET, SO_ERROR, (char *)&sockopt, &len);
