@@ -16,9 +16,9 @@ public:
 	}
 	void run()
 	{
-		tcpstream tcp("127.0.0.1:9000");
+		TCPStream tcp("127.0.0.1:9000");
 		tcp << "pippo" << endl;
-		tcp.close();
+		tcp.disconnect();
 	}
 };
 
@@ -32,10 +32,10 @@ int main(int argc, char *argv[])
 	ThreadOut thread;
 	while (1){
 		if (sock->isPendingConnection()){
-			tcpstream tcp(*sock);
+			TCPStream tcp(*sock);
 			tcp.getline(line, 200);
 			cout << line << endl;
-			tcp.close();
+			tcp.disconnect();
 			return 0;
 		}
 	}
